Class: MotionSupport::Inflector::Inflections
- Inherits:
-
Object
- Object
- MotionSupport::Inflector::Inflections
- Defined in:
- lib/motion-support/inflector/inflections.rb
Overview
A singleton instance of this class is yielded by Inflector.inflections, which can then be used to specify additional inflection rules.
MotionSupport::Inflector.inflections do |inflect|
inflect.plural /^(ox)$/i, '\1\2en'
inflect.singular /^(ox)en/i, '\1'
inflect.irregular 'octopus', 'octopi'
inflect.uncountable 'equipment'
end
New rules are added at the top. So in the example above, the irregular rule for octopus will now be the first of the pluralization and singularization rules that is runs. This guarantees that your rules run before any of the rules that may already have been loaded.
Instance Attribute Summary collapse
-
#acronym_regex ⇒ Object
Returns the value of attribute acronym_regex.
-
#acronyms ⇒ Object
Returns the value of attribute acronyms.
-
#humans ⇒ Object
Returns the value of attribute humans.
-
#plurals ⇒ Object
Returns the value of attribute plurals.
-
#singulars ⇒ Object
Returns the value of attribute singulars.
-
#uncountables ⇒ Object
Returns the value of attribute uncountables.
Class Method Summary collapse
Instance Method Summary collapse
-
#acronym(word) ⇒ Object
Specifies a new acronym.
-
#clear(scope = :all) ⇒ Object
Clears the loaded inflections within a given scope (default is
:all). - #define_plurals(s0, srest, p0, prest) ⇒ Object
- #define_singulars(s0, srest, p0, prest) ⇒ Object
-
#human(rule, replacement) ⇒ Object
Specifies a humanized form of a string by a regular expression rule or by a string mapping.
-
#initialize ⇒ Inflections
constructor
A new instance of Inflections.
-
#initialize_dup(orig) ⇒ Object
Private, for the test suite.
-
#irregular(singular, plural) ⇒ Object
Specifies a new irregular that applies to both pluralization and singularization at the same time.
-
#plural(rule, replacement) ⇒ Object
Specifies a new pluralization rule and its replacement.
-
#singular(rule, replacement) ⇒ Object
Specifies a new singularization rule and its replacement.
-
#uncountable(*words) ⇒ Object
Add uncountable words that shouldn’t be attempted inflected.
Constructor Details
#initialize ⇒ Inflections
Returns a new instance of Inflections.
28 29 30 |
# File 'lib/motion-support/inflector/inflections.rb', line 28 def initialize @plurals, @singulars, @uncountables, @humans, @acronyms, @acronym_regex = [], [], [], [], {}, /(?=a)b/ end |
Instance Attribute Details
#acronym_regex ⇒ Object
Returns the value of attribute acronym_regex.
26 27 28 |
# File 'lib/motion-support/inflector/inflections.rb', line 26 def acronym_regex @acronym_regex end |
#acronyms ⇒ Object
Returns the value of attribute acronyms.
26 27 28 |
# File 'lib/motion-support/inflector/inflections.rb', line 26 def acronyms @acronyms end |
#humans ⇒ Object
Returns the value of attribute humans.
26 27 28 |
# File 'lib/motion-support/inflector/inflections.rb', line 26 def humans @humans end |
#plurals ⇒ Object
Returns the value of attribute plurals.
26 27 28 |
# File 'lib/motion-support/inflector/inflections.rb', line 26 def plurals @plurals end |
#singulars ⇒ Object
Returns the value of attribute singulars.
26 27 28 |
# File 'lib/motion-support/inflector/inflections.rb', line 26 def singulars @singulars end |
#uncountables ⇒ Object
Returns the value of attribute uncountables.
26 27 28 |
# File 'lib/motion-support/inflector/inflections.rb', line 26 def uncountables @uncountables end |
Class Method Details
.instance ⇒ Object
22 23 24 |
# File 'lib/motion-support/inflector/inflections.rb', line 22 def self.instance @__instance__ ||= new end |
Instance Method Details
#acronym(word) ⇒ Object
Specifies a new acronym. An acronym must be specified as it will appear in a camelized string. An underscore string that contains the acronym will retain the acronym when passed to camelize, humanize, or titleize. A camelized string that contains the acronym will maintain the acronym when titleized or humanized, and will convert the acronym into a non-delimited single lowercase word when passed to underscore.
acronym 'HTML'
titleize 'html' #=> 'HTML'
camelize 'html' #=> 'HTML'
underscore 'MyHTML' #=> 'my_html'
The acronym, however, must occur as a delimited unit and not be part of another word for conversions to recognize it:
acronym 'HTTP'
camelize 'my_http_delimited' #=> 'MyHTTPDelimited'
camelize 'https' #=> 'Https', not 'HTTPs'
underscore 'HTTPS' #=> 'http_s', not 'https'
acronym 'HTTPS'
camelize 'https' #=> 'HTTPS'
underscore 'HTTPS' #=> 'https'
Note: Acronyms that are passed to pluralize will no longer be recognized, since the acronym will not occur as a delimited unit in the pluralized result. To work around this, you must specify the pluralized form as an acronym as well:
acronym 'API'
camelize(pluralize('api')) #=> 'Apis'
acronym 'APIs'
camelize(pluralize('api')) #=> 'APIs'
acronym may be used to specify any word that contains an acronym or otherwise needs to maintain a non-standard capitalization. The only restriction is that the word must begin with a capital letter.
acronym 'RESTful'
underscore 'RESTful' #=> 'restful'
underscore 'RESTfulController' #=> 'restful_controller'
titleize 'RESTfulController' #=> 'RESTful Controller'
camelize 'restful' #=> 'RESTful'
camelize 'restful_controller' #=> 'RESTfulController'
acronym 'McDonald'
underscore 'McDonald' #=> 'mcdonald'
camelize 'mcdonald' #=> 'McDonald'
112 113 114 115 |
# File 'lib/motion-support/inflector/inflections.rb', line 112 def acronym(word) @acronyms[word.downcase] = word @acronym_regex = /#{@acronyms.values.join("|")}/ end |
#clear(scope = :all) ⇒ Object
Clears the loaded inflections within a given scope (default is :all). Give the scope as a symbol of the inflection type, the options are: :plurals, :singulars, :uncountables, :humans.
clear :all
clear :plurals
214 215 216 217 218 219 220 221 |
# File 'lib/motion-support/inflector/inflections.rb', line 214 def clear(scope = :all) case scope when :all @plurals, @singulars, @uncountables, @humans = [], [], [], [] else instance_variable_set "@#{scope}", [] end end |
#define_plurals(s0, srest, p0, prest) ⇒ Object
172 173 174 175 176 177 |
# File 'lib/motion-support/inflector/inflections.rb', line 172 def define_plurals(s0, srest, p0, prest) plural(/#{s0.upcase}(?i)#{srest}$/, p0.upcase + prest) plural(/#{s0.downcase}(?i)#{srest}$/, p0.downcase + prest) plural(/#{p0.upcase}(?i)#{prest}$/, p0.upcase + prest) plural(/#{p0.downcase}(?i)#{prest}$/, p0.downcase + prest) end |
#define_singulars(s0, srest, p0, prest) ⇒ Object
179 180 181 182 183 184 |
# File 'lib/motion-support/inflector/inflections.rb', line 179 def define_singulars(s0, srest, p0, prest) singular(/#{s0.upcase}(?i)#{srest}$/, s0.upcase + srest) singular(/#{s0.downcase}(?i)#{srest}$/, s0.downcase + srest) singular(/#{p0.upcase}(?i)#{prest}$/, s0.upcase + srest) singular(/#{p0.downcase}(?i)#{prest}$/, s0.downcase + srest) end |
#human(rule, replacement) ⇒ Object
Specifies a humanized form of a string by a regular expression rule or by a string mapping. When using a regular expression based replacement, the normal humanize formatting is called after the replacement. When a string is used, the human form should be specified as desired (example: ‘The name’, not ‘the_name’).
human /_cnt$/i, '\1_count'
human 'legacy_col_person_name', 'Name'
203 204 205 |
# File 'lib/motion-support/inflector/inflections.rb', line 203 def human(rule, replacement) @humans.prepend([rule, replacement]) end |
#initialize_dup(orig) ⇒ Object
Private, for the test suite.
33 34 35 36 37 |
# File 'lib/motion-support/inflector/inflections.rb', line 33 def initialize_dup(orig) # :nodoc: %w(plurals singulars uncountables humans acronyms acronym_regex).each do |scope| instance_variable_set("@#{scope}", orig.send(scope).dup) end end |
#irregular(singular, plural) ⇒ Object
Specifies a new irregular that applies to both pluralization and singularization at the same time. This can only be used for strings, not regular expressions. You simply pass the irregular in singular and plural form.
irregular 'octopus', 'octopi'
irregular 'person', 'people'
144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/motion-support/inflector/inflections.rb', line 144 def irregular(singular, plural) @uncountables.delete(singular) @uncountables.delete(plural) s0 = singular[0] srest = singular[1..-1] p0 = plural[0] prest = plural[1..-1] if s0.upcase == p0.upcase plural(/(#{s0})#{srest}$/i, '\1' + prest) plural(/(#{p0})#{prest}$/i, '\1' + prest) singular(/(#{s0})#{srest}$/i, '\1' + srest) singular(/(#{p0})#{prest}$/i, '\1' + srest) else # define_plurals and define_singulars arose from a strange error where # the app would quit with absolutely no output (not even VM Aborting!). # The only way to turn off the error was to comment out some lines, but # it didn't really matter which ones, as long as you commented out 4 or 5. # So I split them out like this on a whim and it seems to have solved the problem. # Weird!! define_plurals(s0, srest, p0, prest) define_singulars(s0, srest, p0, prest) end end |
#plural(rule, replacement) ⇒ Object
Specifies a new pluralization rule and its replacement. The rule can either be a string or a regular expression. The replacement should always be a string that may include references to the matched data from the rule.
121 122 123 124 125 |
# File 'lib/motion-support/inflector/inflections.rb', line 121 def plural(rule, replacement) @uncountables.delete(rule) if rule.is_a?(String) @uncountables.delete(replacement) @plurals.prepend([rule, replacement]) end |
#singular(rule, replacement) ⇒ Object
Specifies a new singularization rule and its replacement. The rule can either be a string or a regular expression. The replacement should always be a string that may include references to the matched data from the rule.
131 132 133 134 135 |
# File 'lib/motion-support/inflector/inflections.rb', line 131 def singular(rule, replacement) @uncountables.delete(rule) if rule.is_a?(String) @uncountables.delete(replacement) @singulars.prepend([rule, replacement]) end |
#uncountable(*words) ⇒ Object
Add uncountable words that shouldn’t be attempted inflected.
uncountable 'money'
uncountable 'money', 'information'
uncountable %w( money information rice )
191 192 193 |
# File 'lib/motion-support/inflector/inflections.rb', line 191 def uncountable(*words) (@uncountables << words).flatten! end |